<?php
/**
 * Class for parameter-based Revenue Reports querying
 *
 * Example usage:
 * $args = array(
 *          'before' => '2018-07-19 00:00:00',
 *          'after'  => '2018-07-05 00:00:00',
 *          'interval' => 'week',
 *         );
 * $report = new WC_Reports_Revenue_Query( $args );
 * $mydata = $report->get_data();
 *
 * @package  WooCommerce/Classes
 * @version  3.5.0
 * @since    3.5.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * WC_Reports_Revenue_Query
 *
 * @version  3.5.0
 */
class WC_Reports_Revenue_Query extends WC_Reports_Query {

	/**
	 * Valid query vars for Revenue report.
	 *
	 * @return array
	 */
	protected function get_default_query_vars() {
		return array(
			'fields' => array(
				'date_start',
				'date_end',
				'num_orders',
				'num_items_sold',
				'orders_gross_total',
				'orders_coupon_total',
				'orders_refund_total',
				'orders_tax_total',
				'orders_shipping_total',
				'orders_net_total',
			),
		);
	}

	/**
	 * Get revenue data based on the current query vars.
	 *
	 * @return array
	 */
	public function get_data() {
		$args    = apply_filters( 'woocommerce_reports_revenue_query_args', $this->get_query_vars() );
		$results = WC_Data_Store::load( 'revenue-report' )->get_data( $args );
		return apply_filters( 'woocommerce_reports_revenue_select_query', $results, $args );
	}

}
